@@ -1,5 +1,5 @@
 """
- Copyright (c) 2015-2019 Alan Yorinks All rights reserved.
+ Copyright (c) 2015-2021 Alan Yorinks All rights reserved.
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
@@ -42,6 +42,42 @@ class PrivateConstants:
     SET_ANALOG_SCANNING_INTERVAL = 16
     ENABLE_ALL_REPORTS = 17
     RESET = 18
+    SPI_INIT = 19
+    SPI_WRITE_BLOCKING = 20
+    SPI_READ_BLOCKING = 21
+    SPI_SET_FORMAT = 22
+    SPI_CS_CONTROL = 23
+    ONE_WIRE_INIT = 24
+    ONE_WIRE_RESET = 25
+    ONE_WIRE_SELECT = 26
+    ONE_WIRE_SKIP = 27
+    ONE_WIRE_WRITE = 28
+    ONE_WIRE_READ = 29
+    ONE_WIRE_RESET_SEARCH = 30
+    ONE_WIRE_SEARCH = 31
+    ONE_WIRE_CRC8 = 32
+    SET_PIN_MODE_STEPPER = 33
+    STEPPER_MOVE_TO = 34
+    STEPPER_MOVE = 35
+    STEPPER_RUN = 36
+    STEPPER_RUN_SPEED = 37
+    STEPPER_SET_MAX_SPEED = 38
+    STEPPER_SET_ACCELERATION = 39
+    STEPPER_SET_SPEED = 40
+    STEPPER_SET_CURRENT_POSITION = 41
+    STEPPER_RUN_SPEED_TO_POSITION = 42
+    STEPPER_STOP = 43
+    STEPPER_DISABLE_OUTPUTS = 44
+    STEPPER_ENABLE_OUTPUTS = 45
+    STEPPER_SET_MINIMUM_PULSE_WIDTH = 46
+    STEPPER_SET_ENABLE_PIN = 47
+    STEPPER_SET_3_PINS_INVERTED = 48
+    STEPPER_SET_4_PINS_INVERTED = 49
+    STEPPER_IS_RUNNING = 50
+    STEPPER_GET_CURRENT_POSITION = 51
+    STEPPER_GET_DISTANCE_TO_GO = 52
+    STEPPER_GET_TARGET_POSITION = 53
+    GET_FEATURES = 54
 
     # reports
     # debug data from Arduino
@@ -55,10 +91,17 @@ class PrivateConstants:
     I2C_READ_REPORT = 10
     SONAR_DISTANCE = 11
     DHT_REPORT = 12
-
+    SPI_REPORT = 13
+    ONE_WIRE_REPORT = 14
+    STEPPER_DISTANCE_TO_GO = 15
+    STEPPER_TARGET_POSITION = 16
+    STEPPER_CURRENT_POSITION = 17
+    STEPPER_RUNNING_REPORT = 18
+    STEPPER_RUN_COMPLETE_REPORT = 19
+    FEATURES = 20
     DEBUG_PRINT = 99
 
-    TELEMETRIX_VERSION = "1.6"
+    TELEMETRIX_VERSION = "1.8"
 
     # reporting control
     REPORTING_DISABLE_ALL = 0
@@ -92,3 +135,11 @@ class PrivateConstants:
     # DHT Report sub-types
     DHT_DATA = 0
     DHT_ERROR = 1
+
+    # feature masks
+    ONEWIRE_FEATURE = 0x01
+    DHT_FEATURE = 0x02
+    STEPPERS_FEATURE = 0x04
+    SPI_FEATURE = 0x08
+    SERVO_FEATURE = 0x10
+    SONAR_FEATURE = 0x20
